# Generated by roxygen2: do not edit by hand

S3method(base::as.data.frame,scopus_records)
S3method(c,scopus_records)
S3method(format,scopus_search_report)
S3method(ggplot2::autoplot,scopus_comparison)
S3method(ggplot2::autoplot,scopus_intersections)
S3method(ggplot2::autoplot,scopus_records)
S3method(ggplot2::autoplot,scopus_top)
S3method(ggplot2::autoplot,scopus_trend)
S3method(grid::makeContent,sf_endlabels)
S3method(print,scopus_abstracts)
S3method(print,scopus_comparison)
S3method(print,scopus_doi_diff)
S3method(print,scopus_intersections)
S3method(print,scopus_plan)
S3method(print,scopus_records)
S3method(print,scopus_records_summary)
S3method(print,scopus_search_report)
S3method(print,scopus_trend)
S3method(summary,scopus_records)
S3method(tibble::as_tibble,scopus_records)
export(as_bibliometrix)
export(as_bibtex)
export(as_ris)
export(is_scopus_plan)
export(is_scopus_records)
export(plot_scopus_comparison)
export(plot_scopus_intersections)
export(plot_scopus_top)
export(plot_scopus_trend)
export(read_scopus_records)
export(run_app)
export(scopus_abstract)
export(scopus_cache_clear)
export(scopus_cache_dir)
export(scopus_combine)
export(scopus_compare_topics)
export(scopus_corpus)
export(scopus_count)
export(scopus_diff_dois)
export(scopus_extract_dois)
export(scopus_fetch)
export(scopus_fetch_plan)
export(scopus_field_tags)
export(scopus_has_key)
export(scopus_intersections)
export(scopus_plan)
export(scopus_query)
export(scopus_quota)
export(scopus_records)
export(scopus_search_report)
export(scopus_top)
export(scopus_trend)
export(write_scopus_records)
importFrom(rlang,.data)
importFrom(rlang,abort)
importFrom(rlang,inform)
importFrom(rlang,warn)
